@@ -16,11 +16,6 @@ Default database operations, with unquoted names.
 class DatabaseOperations(BaseDatabaseOperations):
 	compiler_module = "salesforce.backend.compiler"
 	
-	def __init__(self, connection):
-		# not calling superclass constructor to maintain Django 1.3 support
-		self.connection = connection
-		self._cache = None
-	
 	def connection_init(self):
 		pass
 	
